import React, { useCallback, useMemo, useContext, } from 'react';
import { UnControlled as CodeMirror } from 'react-codemirror2';
import { store, ActionType } from '../store';
import { CMOptions, prefixCls, } from '../config';
import { initDocTag, parseMarks, } from '../utils';
const Code = ({ value = '', }) => {
    const { state: { fields, }, dispatch, } = useContext(store);
    const onReady = useCallback((editorConfig, editorValueParam) => {
        dispatch({
            type: ActionType.SetEditor,
            editor: editorConfig,
        });
        if (!editorValueParam) {
            initDocTag(editorConfig, editorValueParam, fields);
        }
    }, []);
    const handleChange = useCallback((editorConfig, data, editorValueParam) => {
        const _editorValue = editorValueParam ? parseMarks(editorValueParam) : editorValueParam;
        initDocTag(editorConfig, _editorValue, fields);
        dispatch({
            type: ActionType.SetEditorValue,
            editorValue: _editorValue,
        });
    }, []);
    return useMemo(() => (React.createElement(CodeMirror, { className: `${prefixCls}-code-mirror`, autoCursor: false, value: value, options: CMOptions, editorDidMount: onReady, onChange: handleChange })), [value]);
};
export default Code;
