import React, { Fragment, useContext, useCallback, useMemo, } from 'react';
import { Icon } from 'polaris-react-component';
import { store, ActionType } from '../store';
import { prefixCls, CustomFieldIcon } from '../config';
const SelectPanel = () => {
    const { state: { editor, fields, functions, }, dispatch, } = useContext(store);
    const emptyField = !(fields === null || fields === void 0 ? void 0 : fields.length);
    const emptyFunctions = !functions.length;
    const selectItem = useCallback((item) => (event) => {
        event.stopPropagation();
        dispatch({
            type: ActionType.SetCurrentFieldOrFunction,
            currentFieldOrFunction: item,
        });
    }, []);
    const clickItem = useCallback((name, isField) => (event) => {
        event.stopPropagation();
        if (!editor)
            return;
        const doc = editor.getDoc();
        const pos = doc.getCursor();
        if (isField) {
            doc.replaceRange(`{${name}}`, pos, pos);
            editor.focus();
        }
        else {
            doc.replaceRange(`${name}()`, pos);
            pos.ch += name.length + 1;
            doc.setCursor(pos);
            editor.focus();
        }
        dispatch({
            type: ActionType.SetEditorValue,
            editorValue: isField ? `{${name}}` : `${name}()`,
            isSelected: true,
        });
    }, [editor]);
    return useMemo(() => (React.createElement("div", { className: `${prefixCls}-select-panel-layout` }, !emptyFunctions || !emptyField
        ? (React.createElement(React.Fragment, null,
            !emptyField && React.createElement("h3", null, "\u6781\u661F\u5B57\u6BB5"), fields === null || fields === void 0 ? void 0 :
            fields.map((field) => (React.createElement("div", { className: `${prefixCls}-select-panel-layout-list-item`, key: field.value, onMouseEnter: selectItem(field), onClick: clickItem(field.value, true) },
                React.createElement(Icon, { type: CustomFieldIcon[field.type] }),
                React.createElement("span", null, field.label)))),
            functions.map(({ name, functions: _functions }, index) => (React.createElement(Fragment, { key: index },
                React.createElement("h3", null, name),
                _functions.map((item) => React.createElement("div", { className: `${prefixCls}-select-panel-layout-list-item`, key: item.name, onMouseEnter: selectItem(item), onClick: clickItem(item.name, false) },
                    React.createElement(Icon, { type: CustomFieldIcon[item.type] }),
                    React.createElement("span", null, item.name))))))))
        : React.createElement("h3", null, "\u6682\u65E0\u641C\u7D22\u7ED3\u679C"))), [editor, fields, functions]);
};
export default SelectPanel;
