import React, { useCallback, useMemo, memo, useContext, Suspense, lazy, useEffect, } from 'react';
import { chunk } from 'lodash-es';
import { Icon } from 'polaris-react-component';
import { Modal, Tooltip } from 'antd';
import 'codemirror/lib/codemirror.css';
import 'antd/lib/tooltip/style/index';
import 'antd/lib/modal/style/index';
import { store, ActionType } from '../store';
import { ErrorType } from '../enum';
import { prefixCls } from '../config';
import { evil, parseFormula, parseFieldData, parseKeyReplaceField, } from '../utils';
const Code = lazy(() => import('./Code'));
const Content = lazy(() => import('./Content'));
const ErrorText = lazy(() => import('./ErrorText'));
const Editor = ({ value = '', style, className, field, dataSource, onChange, }) => {
    const { state: { disabled, editorValue, modalVisible, }, dispatch, } = useContext(store);
    const classnames = [prefixCls, className].join(' ');
    useEffect(() => {
        dispatch({
            type: ActionType.SetFields,
            fields: field,
            dataSource,
        });
    }, [field, dataSource]);
    const cancelModal = useCallback(() => dispatch({
        type: ActionType.SetModalVisible,
        modalVisible: false,
    }), []);
    const confirmModal = useCallback(() => {
        try {
            const activeFieldLength = document.querySelectorAll('.formula-tag').length;
            const callbackDataLength = dataSource === null || dataSource === void 0 ? void 0 : dataSource.length;
            const fieldsData = parseFieldData(editorValue, dataSource);
            const chunkFields = chunk(fieldsData, activeFieldLength);
            if (chunkFields.length) {
                const resultValue = new Array(callbackDataLength);
                for (let i = 0; i < chunkFields.length; i += 1) {
                    const fieldReg = editorValue.match(/\{.*?\}/g);
                    if (!fieldReg)
                        return;
                    const validFiled = parseKeyReplaceField(fieldReg, editorValue, chunkFields[i]);
                    resultValue[i] = parseFormula(evil(validFiled));
                }
                onChange === null || onChange === void 0 ? void 0 : onChange({
                    value: resultValue,
                    formula: editorValue,
                });
            }
            else {
                const calcResult = parseFormula(evil(editorValue));
                onChange === null || onChange === void 0 ? void 0 : onChange({
                    value: calcResult,
                    formula: editorValue,
                });
                dispatch({
                    type: ActionType.SetErrorText,
                    errorCode: ErrorType.Pass,
                    errorText: '',
                });
            }
        }
        catch ({ message }) {
            dispatch({
                type: ActionType.SetErrorText,
                errorCode: ErrorType.Error,
                errorText: message,
            });
            throw message;
        }
    }, [editorValue, dataSource]);
    return useMemo(() => (React.createElement(Modal, { open: modalVisible, closable: false, maskClosable: false, okText: "\u786E\u8BA4", cancelText: '\u53D6\u6D88', okButtonProps: { disabled }, onCancel: cancelModal, onOk: confirmModal },
        React.createElement(Suspense, { fallback: '加载中...' },
            React.createElement("div", { className: classnames, style: style },
                React.createElement("div", { className: `${prefixCls}-layout` },
                    React.createElement("h2", null, "\u8BF7\u8F93\u5165\u516C\u5F0F"),
                    React.createElement(Tooltip, { title: "\u70B9\u51FB\u4E86\u89E3\u516C\u5F0F\u6280\u5DE7" },
                        React.createElement(Icon, { type: "icondoubt" })),
                    React.createElement(Code, { value: value }),
                    React.createElement(ErrorText, null),
                    React.createElement("h2", null, "\u9009\u62E9\u6781\u661F\u5B57\u6BB5\u6216\u51FD\u6570"),
                    React.createElement(Content, null)))))), [modalVisible, disabled, editorValue, dataSource]);
};
export default memo(Editor);
