import React, { createContext, useReducer, useMemo, } from 'react';
import { ErrorType } from '../enum';
import { Functions } from '../config';
import { initialState } from './initialState';
import ActionType from './actionType';
import { parseField, getFormulaError, fuzzySearchField, fuzzySearchFunctions, } from '../utils';
export const store = createContext({ state: initialState });
const { Provider } = store;
export const Store = ({ children }) => {
    const [state, dispatch] = useReducer((originalState, action) => {
        switch (action.type) {
            case ActionType.SetModalVisible: {
                return Object.assign(Object.assign({}, originalState), { modalVisible: action.modalVisible });
            }
            case ActionType.SetCurrentFieldOrFunction: {
                return Object.assign(Object.assign({}, originalState), { currentFieldOrFunction: action.currentFieldOrFunction });
            }
            case ActionType.SetEditor: {
                return Object.assign(Object.assign({}, originalState), { editor: action.editor });
            }
            case ActionType.SetEditorValue: {
                const { editorValue, isSelected } = action;
                const { originalFields: fields, editorValue: originalEditorValue } = originalState;
                const [errorCode, errorText] = getFormulaError(editorValue);
                if (isSelected) {
                    return Object.assign(Object.assign({}, originalState), { editorValue: originalEditorValue, fields, functions: Functions, errorText,
                        errorCode, disabled: Number(errorCode) > -1 });
                }
                const reg = /[\\ \\,\\，]/g;
                if (reg.test(editorValue)) {
                    const result = [...editorValue.matchAll(reg)];
                    if (result) {
                        const lastResult = result.at(-1);
                        if (lastResult) {
                            const { index } = lastResult;
                            const _editorValue = editorValue.slice(Number(index) + 1);
                            return Object.assign(Object.assign({}, originalState), { editorValue, fields: fuzzySearchField(fields, _editorValue), functions: fuzzySearchFunctions(Functions, _editorValue), errorText,
                                errorCode, disabled: Number(errorCode) > -1 });
                        }
                    }
                    return Object.assign(Object.assign({}, originalState), { editorValue,
                        fields, functions: Functions, errorText,
                        errorCode, disabled: Number(errorCode) > -1 });
                }
                console.log('fuzzysearch =====>', 'editorValue:', editorValue, 'originalEditorValue:', originalEditorValue);
                return Object.assign(Object.assign({}, originalState), { editorValue, fields: fuzzySearchField(fields, editorValue), functions: fuzzySearchFunctions(Functions, editorValue), errorText,
                    errorCode, disabled: Number(errorCode) > -1 });
            }
            case ActionType.SetErrorText: {
                return Object.assign(Object.assign({}, originalState), { errorText: action.errorText, errorCode: action.errorCode, disabled: action.errorCode !== ErrorType.Pass });
            }
            case ActionType.SetFields: {
                const { fields, dataSource } = action;
                const _fields = !(fields === null || fields === void 0 ? void 0 : fields.length)
                    ? []
                    : parseField(fields, dataSource);
                return Object.assign(Object.assign({}, originalState), { fields: _fields, originalFields: _fields.slice(0) });
            }
            default: {
                return originalState;
            }
        }
    }, initialState);
    const value = useMemo(() => ({ state, dispatch }), [state]);
    return React.createElement(Provider, { value: value }, children);
};
