import { Fields, FieldName } from '../enum';
import { filterFieldData } from './filter';
export const parseKey = (rawKey) => rawKey.match(/(?<=\{)(.+?)(?=\})/g);
export const parseKeyReplaceField = (fields, originalField, replacedFields) => {
    let _originalField = originalField;
    for (let i = 0; i < fields.length; i += 1) {
        _originalField = _originalField.replace(fields[i], `${replacedFields[i]}`);
    }
    return _originalField;
};
export const parseField = (rawFields, dataSource) => {
    const formatFields = rawFields
        .map(({ name: value, label, field: { type }, }) => ({
        label, value, type, _value: [],
    }))
        .filter(({ type, value }) => ![
        Fields.Annex,
        Fields.BaRelating,
        Fields.WorkingHours,
        Fields.Checkbox,
        Fields.GroupSelect,
    ].includes(type)
        && value !== FieldName.Code);
    for (let i = 0; i < formatFields.length; i += 1) {
        for (let j = 0; j < dataSource.length; j += 1) {
            const { value } = formatFields[i];
            formatFields[i]._value.push((dataSource[j][value]));
        }
    }
    return formatFields;
};
export const parseFieldData = (key, sourceData) => {
    const fieldKey = parseKey(key);
    if (!fieldKey || !Array.isArray(fieldKey))
        return null;
    const data = [];
    for (let i = 0; i < sourceData.length; i += 1) {
        for (let j = 0; j < fieldKey.length; j += 1) {
            if (fieldKey[j] in sourceData[i]) {
                data.push(sourceData[i][fieldKey[j]]);
            }
            else {
                data.push(undefined);
            }
        }
    }
    return filterFieldData(data);
};
export const parseFullFieldData = (fields, sourceData) => {
    const fieldArray = fields
        .map(({ value }) => value)
        .filter(Boolean);
    const fieldObject = {};
    for (let j = 0; j < fieldArray.length; j += 1) {
        fieldObject[fieldArray[j]] = [];
    }
    for (let i = 0; i < sourceData.length; i += 1) {
        for (let k = 0; k < fields.length; k += 1) {
            const { value } = fields[k];
            fieldObject[value].push(sourceData[i][value]);
        }
    }
    return fieldObject;
};
export const parseFormula = (result) => {
    const type = typeof result;
    switch (type) {
        case 'number': {
            if (!Number.isFinite(result))
                return 0;
            if (Number.isInteger(result))
                return result;
            return result.toFixed(4);
        }
        default: {
            return result;
        }
    }
};
export const parseMarks = (rawString) => rawString
    .replace(/，/g, ',')
    .replace(/【/g, '[')
    .replace(/】/g, ']')
    .replace(/（/g, '(')
    .replace(/）/g, ')')
    .replace(/：/g, ':');
