import * as formulajs from '@formulajs/formulajs';
import { ErrorType } from '../enum';
const replaceVariable = (editor, begin, end, val) => {
    const doc = editor.getDoc();
    const el = document.createElement('span');
    el.innerText = val.label;
    el.className = 'formula-tag';
    doc.markText(begin, end, {
        replacedWith: el,
    });
};
export const initLineTag = (editor, content, line, innerVariables = []) => {
    (innerVariables || []).forEach((variable) => {
        const variableMark = `{${variable.value}}`;
        const regex = new RegExp(variableMark, 'g');
        while (regex.exec(content) !== null) {
            const begin = { line, ch: regex.lastIndex - variableMark.length };
            const end = { line, ch: regex.lastIndex };
            replaceVariable(editor, begin, end, variable);
        }
    });
};
export const initDocTag = (editor, code, innerVariables = []) => {
    const contents = code.split('\n');
    contents.forEach((content, idx) => initLineTag(editor, content, idx, innerVariables));
};
export const evil = (expression) => {
    let _expression;
    try {
        _expression = Function(`"use strict";return (${expression})`)();
    }
    catch ({ message }) {
        _expression = Function(`"use strict";return (${JSON.stringify(expression)})`)();
    }
    return _expression;
};
export const injectWindowApi = () => {
    Object.keys(formulajs).forEach((key) => {
        if (!Object.prototype.hasOwnProperty.call(window, key)) {
            window[key] = formulajs[key];
        }
    });
};
export const getFormulaError = (input) => {
    if (/^[\x\\÷\\+\-\\*\\/]/.test(input)) {
        return [ErrorType.Error, '开头错误'];
    }
    if (/[\x\\÷\\+\-\\*\\/]$/.test(input)) {
        return [ErrorType.Error, '结尾错误'];
    }
    if (/[\x\\÷\\+\-\\*\\/]{2,}/.test(input)) {
        return [ErrorType.Error, '连续运算'];
    }
    if (/\([\x\\÷\\+\-\\*\\/]/.test(input)) {
        return [ErrorType.Error, '( 后非法运算'];
    }
    if (/[\x\\÷\\+\-\\*\\/]\)/.test(input)) {
        return [ErrorType.Error, ') 后非法运算'];
    }
    if (/[@#\\$%\\^&\\]+/g.test(input)) {
        return [ErrorType.Unknown, input];
    }
    return [ErrorType.Pass, ''];
};
export const fuzzySearchField = (fields, inputValue) => {
    const _fields = [];
    if (fields && fields.length) {
        for (let i = 0; i < fields.length; i += 1) {
            if (fields[i].label.indexOf(inputValue) !== -1) {
                _fields.push(fields[i]);
            }
        }
    }
    return _fields;
};
export const fuzzySearchFunctions = (functionArray, inputValue) => {
    const _functions = [];
    for (let i = 0; i < functionArray.length; i += 1) {
        const { functions } = functionArray[i];
        for (let k = 0; k < functions.length; k += 1) {
            if (functions[k].name.indexOf(inputValue.toUpperCase()) !== -1) {
                const { name } = functionArray[i];
                const alreadyName = _functions.findIndex((item) => {
                    if ('name' in item) {
                        return item.name === name;
                    }
                    return false;
                });
                if (alreadyName !== -1) {
                    _functions[alreadyName].functions.push(functions[k]);
                }
                else {
                    _functions.push({
                        name,
                        functions: [functions[k]],
                    });
                }
            }
        }
    }
    return _functions;
};
